@@ -26,32 +26,43 @@ from .tools import scipy_signal2d
 
 logger = logging.getLogger(__name__)
 
+DEFAULT_TIMING_MS = {
+    "ton": 250.0,
+    "t1": 8250.0,
+    "t2": 10250.0,
+    "t3": 14250.0,
+    "t4": 16250.0,
+    "toff": 18916.0,
+}
+
 
 class PosCheops(Recording):
 
     # pylint: disable=line-too-long,anomalous-backslash-in-string
 
-    """PosCheops current stimulus
+    r"""PosCheops current stimulus
 
-        hypamp         hypamp+amp          hypamp           hypamp+amp          hypamp           hypamp+amp          hypamp
-          :                 :                 :                  :                 :                  :                 :
-          :                 .                 :                  .                 :                  .                 :
-          :                / \                :                 / \                :                 / \                :
-          :               /   \               :                /   \               :                /   \               :
-          :              /     \              :               /     \              :               /     \              :
-          :             /       \             :              /       \             :              /       \             :
-          :            /         \            :             /         \            :             /         \            :
-          :           /           \           :            /           \           :            /           \           :
-          :          /             \          :           /             \          :           /             \          :
-          :         /               \         :          /               \         :          /               \         :
-          :        /                 \        :         /                 \        :         /                 \        :
-          :       /                   \       :        /                   \       :        /                   \       :
-          :      /                     \      :       /                     \      :       /                     \      :
-    |__________ /                       \ __________ /                       \ __________ /                       \ __________
-    :          :                         :          :                         :          :                         :          ^
-    :          :                         :          :                         :          :                         :          :
-    :          :                         :          :                         :          :                         :          :
-    t=0        ton                       t1         t2                        t3         t4                        toff       tend
+    .. code-block:: none
+
+            hypamp         hypamp+amp          hypamp           hypamp+amp          hypamp           hypamp+amp          hypamp
+              :                 :                 :                  :                 :                  :                 :
+              :                 .                 :                  .                 :                  .                 :
+              :                / \                :                 / \                :                 / \                :
+              :               /   \               :                /   \               :                /   \               :
+              :              /     \              :               /     \              :               /     \              :
+              :             /       \             :              /       \             :              /       \             :
+              :            /         \            :             /         \            :             /         \            :
+              :           /           \           :            /           \           :            /           \           :
+              :          /             \          :           /             \          :           /             \          :
+              :         /               \         :          /               \         :          /               \         :
+              :        /                 \        :         /                 \        :         /                 \        :
+              :       /                   \       :        /                   \       :        /                   \       :
+              :      /                     \      :       /                     \      :       /                     \      :
+        |__________ /                       \ __________ /                       \ __________ /                       \ __________
+        :          :                         :          :                         :          :                         :          ^
+        :          :                         :          :                         :          :                         :          :
+        :          :                         :          :                         :          :                         :          :
+        t=0        ton                       t1         t2                        t3         t4                        toff       tend
     """
 
     def __init__(
@@ -115,8 +126,15 @@ class PosCheops(Recording):
         # Smooth the current
         smooth_current = scipy_signal2d(current, 85)
 
-        self.set_timing_ecode(
-            ["ton", "t1", "t2", "t3", "t4", "toff"], config_data)
+        timing_keys = ["ton", "t1", "t2", "t3", "t4", "toff"]
+        if any(config_data.get(k) is None for k in timing_keys):
+            logger.warning(
+                f"Missing timing key(s) for {self.protocol_name}, using defaults: {DEFAULT_TIMING_MS}"
+            )
+            for k in timing_keys:
+                config_data[k] = DEFAULT_TIMING_MS[k]
+
+        self.set_timing_ecode(timing_keys, config_data)
 
         hypamp_value = numpy.median(smooth_current[: self.ton])
         self.set_amplitudes_ecode("hypamp", config_data, reader_data, hypamp_value)
@@ -140,7 +158,7 @@ class PosCheops(Recording):
         toff = int(self.toff / self.dt)
 
         time = numpy.arange(0.0, self.tend, self.dt)
-        current = numpy.full(time.shape, self.hypamp)
+        current = numpy.full(time.shape, numpy.float64(self.hypamp))
 
         # First peak
         mid = int(0.5 * (self.ton + self.t1) / self.dt)
