@@ -43,6 +43,24 @@ from bluepyefe.auto_targets import default_auto_targets
 logger = logging.getLogger(__name__)
 
 
+def cells_pickle_output_path(output_directory):
+    """Returns the cells.pkl output file path
+
+    Args:
+        output_directory (Path): the output directory
+    """
+    return output_directory / "cells.pkl"
+
+
+def protocols_pickle_output_path(output_directory):
+    """Returns the protocols.pkl output file path
+
+    Args:
+        output_directory (Path): the output directory
+    """
+    return output_directory / "protocols.pkl"
+
+
 def _create_cell(cell_definition, recording_reader, efel_settings=None):
     """
     Initialize a Cell object and populate it with the content of the associated
@@ -173,11 +191,18 @@ def read_recordings(
     Args:
         files_metadata (dict): define for which cell and protocol each file
             has to be used. Of the form:
-            {
-                cell_id: {
-                    protocol_name: [{file_metadata1}, {file_metadata1}]
-                }
-            }
+
+                .. code-block:: python
+
+                    {
+                        cell_id: {
+                            protocol_name: [
+                                {file_metadata1},
+                                {file_metadata1}
+                            ]
+                        }
+                    }
+
             A same file path might be present in the file metadata for
             different protocols.
             The entries required in the file_metadata are specific to each
@@ -225,17 +250,21 @@ def extract_efeatures_at_targets(
         targets (dict): define the efeatures to extract as well as which
             protocols and current amplitude they should be extracted for. Of
             the form:
-            [{
-                "efeature": "AP_amplitude",
-                "protocol": "IDRest",
-                "amplitude": 150.,
-                "tolerance": 10.,
-                "efel_settings": {
-                    'stim_start': 200.,
-                    'stim_end': 500.,
-                    'Threshold': -10.
-                }
-            }]
+
+            .. code-block:: python
+
+                [{
+                    "efeature": "AP_amplitude",
+                    "protocol": "IDRest",
+                    "amplitude": 150.,
+                    "tolerance": 10.,
+                    "efel_settings": {
+                        "stim_start": 200.,
+                        "stim_end": 500.,
+                        "Threshold": -10.
+                    }
+                }]
+
         map_function (function): Function used to map (parallelize) the
             feature extraction operations. Note: the parallelization is
             done across cells an not across efeatures.
@@ -373,17 +402,21 @@ def group_efeatures(
         targets (dict): define the efeatures to extract as well as which
             protocols and current amplitude they should be extracted for. Of
             the form:
-            [{
-                "efeature": "AP_amplitude",
-                "protocol": "IDRest",
-                "amplitude": 150.,
-                "tolerance": 10.,
-                "efel_settings": {
-                    'stim_start': 200.,
-                    'stim_end': 500.,
-                    'Threshold': -10.
-                }
-            }]
+
+            .. code-block:: python
+
+                [{
+                    "efeature": "AP_amplitude",
+                    "protocol": "IDRest",
+                    "amplitude": 150.,
+                    "tolerance": 10.,
+                    "efel_settings": {
+                        "stim_start": 200.,
+                        "stim_end": 500.,
+                        "Threshold": -10.
+                    }
+                }]
+
         absolute_amplitude (bool): if True, will use the absolute amplitude
             instead of the relative amplitudes of the recordings when checking
             if a recording has to be used for a given target.
@@ -418,22 +451,28 @@ def group_efeatures(
         efel_settings=efel_settings,
     )
 
-    for protocol in protocols:
-        for cell in cells:
+    missing_protocols = set()
 
+    for protocol in protocols:
+        found = False
+        for cell in cells:
             if cell.rheobase is None and not absolute_amplitude:
                 continue
+            recordings = cell.get_recordings_by_protocol_name(protocol.name)
+            if not recordings:
+                continue
+            found = True
 
-            for recording in cell.get_recordings_by_protocol_name(
-                    protocol.name
-            ):
-
-                if recording.in_target(
-                    protocol.amplitude,
-                    protocol.tolerance,
-                    absolute_amplitude
-                ):
+            for recording in recordings:
+                if recording.in_target(protocol.amplitude,
+                                       protocol.tolerance,
+                                       absolute_amplitude):
                     protocol.append(recording)
+        if not found:
+            missing_protocols.add(protocol.name)
+
+    for name in missing_protocols:
+        logger.warning(f"Protocol '{name}' not found in any cell recordings.")
 
     return protocols
 
@@ -624,26 +663,32 @@ def _read_extract_low_memory(
 
 
 def convert_legacy_targets(targets):
-    """Convert targets of the form:
-        protocol_name: {
+    """Convert targets of the form::
+
+        .. code-block:: python
+
+            protocol_name: {
                 "amplitudes": [50, 100],
                 "tolerances": [10, 10],
                 "efeatures": {"Spikecount": {'Threshold': -10.}},
                 "location": "soma"
             }
-        }
-    To ones of the form:
-        [{
-            "efeature": "AP_amplitude",
-            "protocol": "IDRest",
-            "amplitude": 150.,
-            "tolerance": 10.,
-            "efel_settings": {
-                'stim_start': 200.,
-                'stim_end': 500.,
-                'Threshold': -10.
-            }
-        }]
+
+    To ones of the form::
+
+        .. code-block:: python
+
+            [{
+                "efeature": "AP_amplitude",
+                "protocol": "IDRest",
+                "amplitude": 150.,
+                "tolerance": 10.,
+                "efel_settings": {
+                    "stim_start": 200.,
+                    "stim_end": 500.,
+                    "Threshold": -10.
+                }
+            }]
     """
 
     formatted_targets = []
@@ -852,12 +897,19 @@ def extract_efeatures(
         output_directory (str): path to the output directory
         files_metadata (dict): define from files to read the data as well as
             the name of the cells and protocols to which these data are
-            related. Of the form:
-            {
-                cell_id: {
-                    protocol_name: [{file_metadata1}, {file_metadata1}]
-                }
-            }
+            related. Of the form::
+
+                .. code-block:: python
+
+                    {
+                        cell_id: {
+                            protocol_name: [
+                                {file_metadata1},
+                                {file_metadata1}
+                            ]
+                        }
+                    }
+
             The entries required in the file_metadata are specific to each
             recording_reader (see bluepyemodel/reader.py to know which one are
             needed for your recording_reader).
@@ -869,18 +921,22 @@ def extract_efeatures(
             rheobase if absolute_amplitude if False or in nA if
             absolute_amplitude is True) they should be extracted.
             If targets are not provided, automatic targets will be used.
-            Of the form:
-            [{
-                "efeature": "AP_amplitude",
-                "protocol": "IDRest",
-                "amplitude": 150.,
-                "tolerance": 10.,
-                "efel_settings": {
-                    'stim_start': 200.,
-                    'stim_end': 500.,
-                    'Threshold': -10.
-                }
-            }]
+            Of the form::
+
+                .. code-block:: python
+
+                    [{
+                        "efeature": "AP_amplitude",
+                        "protocol": "IDRest",
+                        "amplitude": 150.,
+                        "tolerance": 10.,
+                        "efel_settings": {
+                            "stim_start": 200.,
+                            "stim_end": 500.,
+                            "Threshold": -10.
+                        }
+                    }]
+
         threshold_nvalue_save (int): minimum number of values needed for
             an efeatures to be averaged and returned in the output.
         protocols_rheobase (list): names of the protocols that will be
@@ -905,12 +961,16 @@ def extract_efeatures(
         efel_settings (dict): eFEL settings in the form
             {setting_name: setting_value}. If settings are also informed
             in the targets per efeature, the latter will have priority. If
-            None, will be set to:
-            {
-                'strict_stiminterval': True,
-                'Threshold': -20.,
-                'interp_step': 0.025
-            }
+            None, will be set to::
+
+                .. code-block:: python
+
+                    {
+                        "strict_stiminterval": True,
+                        "Threshold": -20.,
+                        "interp_step": 0.025
+                    }
+
         extract_per_cell (bool): if True, also generates the features.json and
             protocol.json for each individual cells.
         rheobase_strategy (str): function used to compute the rheobase. Can be
@@ -931,7 +991,8 @@ def extract_efeatures(
 
     if efel_settings is None:
         logger.warning(
-            "efel_settings is None. Default settings will be used"
+            "efel_settings is None. Default settings will be used: " +
+            str(DEFAULT_EFEL_SETTINGS)
         )
         efel_settings = DEFAULT_EFEL_SETTINGS.copy()
 
@@ -987,6 +1048,7 @@ def extract_efeatures(
             rheobase_strategy,
             rheobase_settings
         )
+
     efeatures, protocol_definitions, current = create_feature_protocol_files(
         cells,
         protocols,
@@ -995,14 +1057,20 @@ def extract_efeatures(
         write_files=write_files,
         default_std_value=default_std_value
     )
+
     if pickle_cells:
         path_cells = pathlib.Path(output_directory)
         path_cells.mkdir(parents=True, exist_ok=True)
-        pickle.dump(cells, open(path_cells / "cells.pkl", 'wb'))
+        pickle.dump(cells, open(cells_pickle_output_path(path_cells), 'wb'))
+        pickle.dump(protocols, open(protocols_pickle_output_path(path_cells), 'wb'))
 
     if plot:
         plot_all_recordings_efeatures(
-            cells, protocols, output_dir=output_directory, mapper=map_function
+            cells,
+            protocols,
+            output_dir=output_directory,
+            mapper=map_function,
+            efel_settings=efel_settings
         )
 
     if extract_per_cell and write_files:
@@ -1037,11 +1105,18 @@ def plot_recordings(
     Args:
         files_metadata (dict): define for which cell and protocol each file
             has to be used. Of the form:
-            {
-                cell_id: {
-                    protocol_name: [{file_metadata1}, {file_metadata1}]
-                }
-            }
+
+                .. code-block:: python
+
+                    {
+                        cell_id: {
+                            protocol_name: [
+                                {file_metadata1},
+                                {file_metadata1}
+                            ]
+                        }
+                    }
+
             A same file path might be present in the file metadata for
             different protocols.
             The entries required in the file_metadata are specific to each
