@@ -25,6 +25,7 @@ import logging
 import numpy
 import efel
 import matplotlib.pyplot as plt
+from pathlib import Path
 
 from .tools import to_ms, to_mV, to_nA, set_efel_settings
 
@@ -67,11 +68,13 @@ class Recording(ABC):
         self.t = None
         self.current = None
         self.voltage = None
+        self.amp = None
+        self.hypamp = None
 
         self.repetition = None
 
         if len(reader_data):
-            self.t, self.current, self.voltage = self.standardize_trace(
+            self.t, self.current, self.voltage, self.amp, self.hypamp = self.standardize_trace(
                 config_data, reader_data
             )
 
@@ -79,6 +82,17 @@ class Recording(ABC):
         self.auto_threshold = None
         self.peak_time = None
 
+    @property
+    def name(self):
+        """Proxy that can be used to name the recording."""
+        if self.id:
+            return self.id
+        if "filepath" in self.config_data and self.config_data["filepath"] is not None:
+            return str(Path(self.config_data["filepath"]).stem)
+        if "v_file" in self.config_data:
+            return str(Path(self.config_data["v_file"]).stem)
+        return ""
+
     @property
     def time(self):
         """Alias of the time attribute"""
@@ -115,12 +129,19 @@ class Recording(ABC):
          given current amplitude is provided. If it isn't use the value
          computed from the current series"""
 
+        unit = config_data.get("i_unit") or reader_data.get("i_unit")
+
+        if unit is None:
+            raise Exception(f"Current unit not configured for file {self.files}")
+
         if amp_name in config_data and config_data[amp_name] is not None:
-            setattr(self, amp_name, config_data[amp_name])
+            amp = to_nA(config_data[amp_name], unit)
         elif amp_name in reader_data and reader_data[amp_name] is not None:
-            setattr(self, amp_name, reader_data[amp_name])
+            amp = to_nA(reader_data[amp_name], unit)
         else:
-            setattr(self, amp_name, value)
+            amp = value
+
+        setattr(self, amp_name, amp)
 
     def index_to_ms(self, name_timing, time_series):
         """Used by some of the children classes to translate a timing attribute
@@ -160,7 +181,7 @@ class Recording(ABC):
     def standardize_trace(self, config_data, reader_data):
         """Standardize the units of the current and voltage times series. If
         some metadata are present both in the file itself and the file_metadata
-         dictionary, the latter is used."""
+        dictionary, the latter is used."""
 
         # Create the time series
         t = numpy.arange(len(reader_data["voltage"]))
@@ -187,10 +208,18 @@ class Recording(ABC):
             )
 
         # Convert current to nA
-        if "i_unit" in config_data and config_data["i_unit"] is not None:
-            current = to_nA(reader_data["current"], config_data["i_unit"])
-        elif "i_unit" in reader_data and reader_data["i_unit"] is not None:
-            current = to_nA(reader_data["current"], reader_data["i_unit"])
+        # Determine the unit to use
+        unit = config_data.get("i_unit") or reader_data.get("i_unit")
+        if unit:
+            current = to_nA(reader_data.get("current", 0), unit)
+
+            # Set amp - prioritize amp in config_data
+            amp_source = config_data if "amp" in config_data else reader_data
+            amp = to_nA(amp_source.get("amp", 0), unit) if "amp" in amp_source else None
+
+            # Set hypamp - prioritize hypamp in config_data
+            hypamp_source = config_data if "hypamp" in config_data else reader_data
+            hypamp = to_nA(hypamp_source.get("hypamp", 0), unit) if "hypamp" in hypamp_source else None
         else:
             raise Exception(
                 "Current unit not configured for " "file {}".format(self.files)
@@ -216,15 +245,14 @@ class Recording(ABC):
         # WARNING: the ljp is informed as a positive float but we substract it
         # from the voltage
         if "ljp" in config_data and config_data["ljp"] is not None:
-            voltage = voltage - config_data["ljp"]
-
+            voltage = numpy.array(voltage) - config_data["ljp"]
         if "repetition" in reader_data:
             self.repetition = reader_data["repetition"]
 
-        return t, current, voltage
+        return t, current, voltage, amp, hypamp
 
     def call_efel(self, efeatures, efel_settings=None):
-        """ Calls efel to computed the wanted efeature """
+        """ Calls efel to compute the wanted efeatures """
 
         if efel_settings is None:
             efel_settings = {}
@@ -239,14 +267,29 @@ class Recording(ABC):
         for setting in efel_settings:
             if setting not in ['stim_start', 'stim_end']:
                 settings[setting] = efel_settings[setting]
+
+        stim_start = efel_settings.get('stim_start', self.ton)
+        stim_end = efel_settings.get('stim_end', self.toff)
+
+        # Special case for SpikeRec
+        if "multiple_decay_time_constant_after_stim" in efeatures:
+            if hasattr(self, "multi_stim_start") and hasattr(self, "multi_stim_end"):
+                settings["multi_stim_start"] = self.multi_stim_start
+                settings["multi_stim_end"] = self.multi_stim_end
+            elif "stim_start" in efel_settings and "stim_end" in efel_settings:
+                settings["multi_stim_start"] = [stim_start]
+                settings["multi_stim_end"] = [stim_end]
+
         set_efel_settings(settings)
 
         efel_trace = {
             "T": self.t,
             "V": self.voltage,
-            'stim_start': [efel_settings.get('stim_start', self.ton)],
-            'stim_end': [efel_settings.get('stim_end', self.toff)]
+            'stim_start': [stim_start],
+            'stim_end': [stim_end]
         }
+        if self.current is not None:
+            efel_trace["I"] = self.current
 
         try:
             return efel.getFeatureValues(
@@ -283,8 +326,11 @@ class Recording(ABC):
         efel_vals = self.call_efel(efeatures, efel_settings)
         for efeature_name, efeature in zip(efeature_names, efeatures):
 
-            value = efel_vals[0][efeature]
-            if value is None or len(value) == 0 or numpy.isinf(numpy.nanmean(value)):
+            if efel_vals[0][efeature] is not None:
+                value = [v for v in efel_vals[0][efeature] if v is not None]
+            else:
+                value = []
+            if len(value) == 0 or numpy.isinf(numpy.nanmean(value)):
                 self.efeatures[efeature_name] = numpy.nan
             else:
                 self.efeatures[efeature_name] = numpy.nanmean(value)
@@ -360,7 +406,8 @@ class Recording(ABC):
             _, axs = plt.subplots(nrows=2, ncols=1, figsize=[4.9, 4.8])
             axis_current, axis_voltage = axs[0], axs[1]
 
-        title = "Amp = {:.03f} nA".format(self.amp)
+        title = "Holding Amp = {:.03f} nA\nAmp = {:.03f} nA".format(
+            self.hypamp, self.amp)
         if self.amp_rel is not None:
             title += self.get_plot_amplitude_title()
         if self.id is not None:
